pub fn render_terminal_diff(report: &DiffReport) -> StringExpand description
Render a human-readable summary of a diff report for the terminal
pub fn render_terminal_diff(report: &DiffReport) -> StringRender a human-readable summary of a diff report for the terminal